#ifndef _ETHERSWITCH_H_
#define _ETHERSWITCH_H_

/*
 *                Copyright 2003, Marvell Semiconductor, Inc.
 * This code contains confidential information of Marvell Semiconductor, Inc.
 * No rights are granted herein under any patent, mask work right or copyright
 * of Marvell or any third party.
 * Marvell reserves the right at its sole discretion to request that this code
 * be immediately returned to Marvell. This code is provided "as is".
 * Marvell makes no warranties, express, implied or otherwise, regarding its
 * accuracy, completeness or performance.
 */ 
/*!
 * \file    etherswitch.h
 * \brief   This file contains the function prototypes and definitions for the 
 *          6060 Ethernet Switch (L2 switch)
 */

//=============================================================================
//                               INCLUDE FILES
//=============================================================================
#include "basic_types.h"
#include "os_if.h"

//=============================================================================
//                          PUBLIC TYPE DEFINITIONS
//=============================================================================
#define etherSwitch_MSG_RCVD               (1<<0)
#define etherSwitch_TIMER_EXPIRED          (1<<1)

/*-------------------------------------*/
/* Ethernet Switch Task Messages       */
/*-------------------------------------*/
typedef struct etherSwitchQ_Msg_t
{
    uint32 command;
    uint32 data;
}
etherSwitchQ_Msg_t;

/*----------------*/
/* Timer Messages */
/*----------------*/
typedef struct etherSwitchQ_TimerMsg_t
{
    uint32 *PendingData_p;
    uint32 Id;
}
etherSwitchQ_TimerMsg_t;
//
// Structure used for messages placed on the Ethernet Task's
// timer message queue. The fields in the structure are:
// 1) PendingData_p - Pointer to relevant saved data
// 2) Id            - ID of the timer
//

//=============================================================================
//                    PUBLIC PROCEDURES (ANSI Prototypes)
//=============================================================================

/******************************************************************************
 * 
 * Name: etherSwitch_Init  
 * 
 * Description: 
 *   This routine is called to initialize the ethernet switch registers and 
 *   ports.
 * 
 * Conditions For Use: 
 *   None. 
 * 
 * Arguments: 
 *   None. 
 * 
 * Return Value: 
 *   Status indicating success or failure 
 * 
 * Notes: 
 *   None. 
 * 
 *****************************************************************************/
extern void etherSwitch_Init( void );

/******************************************************************************
 * 
 * Name: etherSwitchTask_Start 
 * 
 * Description: 
 *   This routine is called to start the Ethernet Switch Management Task running. 
 * 
 * Conditions For Use: 
 *   The task and its associated queues has been initialized by calling 
 *   etherSwitch_Init(). 
 * 
 * Arguments: 
 *   None. 
 * 
 * Return Value: 
 *   None. 
 * 
 * Notes: 
 *   None.
 * 
 *****************************************************************************/
extern void etherSwitchTask_Start( void );

/******************************************************************************
 * 
 * Name: etherSwitchTask_SendEvent 
 * 
 * Description: 
 *   This routine provides the mechanism to trigger an event indicating to 
 *   the Ethernet Switch Task that a message has been written to its 
 *   queue. 
 * 
 * Conditions For Use: 
 *   The task and its associated queues has been initialized by calling 
 *   etherSwitchTask_Init(). 
 * 
 * Arguments: 
 *   Arg1 (i  ): Event - value indicating which queue has received a message 
 * 
 * Return Value: 
 *   Status indicating success or failure 
 * 
 * Notes: 
 *   None. 
 * 
 * 
 *****************************************************************************/
extern Status_e etherSwitchTask_SendEvent( uint32 Event );


/******************************************************************************
 *
 * Name: etherSwitchQ_WriteNoBlock
 *
 * Description:
 *   This routine is called to write a message to the queue where ethernet
 *   switch messages are placed for the Ethernet Switch Service Task. If
 *   writing to the queue cannot immediately occur, then the routine returns
 *   with a failure status (non-blocking).
 *
 * Conditions For Use:
 *   The queue has been initialized by calling etherSwitchQ_Init().
 *
 * Arguments:
 *   Arg1 (i  ): Msg_p - a pointer to the message to be placed on
 *                       the queue
 *
 * Return Value:
 *   Status indicating success or failure
 *
 * Notes:
 *   None.
 *
 *****************************************************************************/
extern Status_e etherSwitchQ_WriteNoBlock( etherSwitchQ_Msg_t *Msg_p );


/******************************************************************************
 * 
 * Name: etherSwitchReset  
 * 
 * Description: 
 *   This routine is resets the ethernet switch using the GPIO port.
 * 
 * Conditions For Use: 
 *   None. 
 * 
 * Arguments: 
 *   None. 
 * 
 * Return Value: 
 *   None. 
 * 
 * Notes: 
 *   None. 
 * 
 * PDL: 
 * END PDL 
 * 
 *****************************************************************************/
extern void etherSwitchReset( void );

#endif /* _ETHERSWITCH_H_ */
