/******************** (c) Marvell Semiconductor, Inc., 2001 *******************
*
* $HEADER$
*
* Purpose:
*    This file contains data types and routines used in accessing the
*    external station information database. This database contains
*    information on other stations (or APs) in a network. The information
*    includes the entity type (AP or station), the MAC address, the power
*    mode, and the station of the entity with respect to the station
*    containing this table.
*
* Public Procedures:
*    extStaDb_AddSta      Add a station to the table
*    extStaDb_DelSta      Delete a station from the table
*    extStaDb_SetState    Set the state of an external station
*    extStaDb_GetState    Get the state of an external station
*
* Notes:
*    None.
*
*****************************************************************************/

#ifndef _EXT_STA_DB_H_
#define _EXT_STA_DB_H_

/*============================================================================= */
/*                               INCLUDE FILES */
/*============================================================================= */
#include "wltypes.h"
#include "IEEE_types.h"
#include "mlme.h"
#include "keyMgmtCommon.h"
#include "keyMgmt.h"


/*============================================================================= */
/*                          PUBLIC TYPE DEFINITIONS */
/*============================================================================= */
typedef enum
{
    LOCATE_SUCCESS,
    ADD_SUCCESS,
    DEL_SUCCESS,
    POWER_SUCCESS,
    STATE_SUCCESS,
    NOT_INITIALIZED,
    LOCATE_FAILURE,
    STATION_EXISTS_ERROR,
    TABLE_ACCESS_ERROR,
    TABLE_FULL_ERROR,
    INVALID_STATE_ERROR,
    NOT_AUTHENTICATED,
    NOT_ASSOCIATED,
    ALREADY_AUTHENTICATED,
    ALREADY_ASSOCIATED,
    ALREADY_AUTHENTICATING,
    ALREADY_ASSOCIATING,
    ALREADY_DEASSOCIATING,
    ALREADY_REASSOCIATING
} extStaDb_Status_e;
/* */
/* The set of possible status responses to operations performed on the table */
/* */

typedef enum
{
    UNAUTHENTICATED = 0,
    SME_INIT_AUTHENTICATING,
    EXT_INIT_AUTHENTICATING,
    AUTHENTICATED,
    SME_INIT_DEAUTHENTICATING,
    EXT_INIT_DEAUTHENTICATING,
    SME_INIT_ASSOCIATING,
    EXT_INIT_ASSOCIATING,
    ASSOCIATED,
    SME_INIT_REASSOCIATING,
    EXT_INIT_REASSOCIATING,
    SME_INIT_DEASSOCIATING,
    EXT_INIT_DEASSOCIATING
} extStaDb_State_e;
/* */
/* The possible states a station or AP can have with respect to the */
/* station containing the external station table */
/* */

typedef enum
{
	BONLY_MODE,
	GONLY_MODE,
	MIXED_MODE
} extStaDb_ClientMode_e;

typedef enum
{
    MYFALSE,
    MYTRUE
}Boolean;

typedef struct extStaDb_StaInfo_t
{
    IEEEtypes_MacAddr_t Addr;
    Boolean AP;
    Boolean SmeInitiated;
    extStaDb_State_e State;
    IEEEtypes_PwrMgmtMode_e PwrMode;
    UINT16 StnId;
    UINT16 Aid;
    UINT32 TimeStamp;
    UINT16 DataFailCnt;
	UINT8 ClientMode;
    /* new State Machine housekeeping */
    AssocSrvSta   mgtAssoc;
    AuthRspSrvSta mgtAuthRsp;
    AuthReqSrvSta mgtAuthReq;
    PowerSaveMonitor pwrSvMon;
    keyMgmthsk_hsm_t keyMgmtHskHsm;
    keyMgmtInfo_t keyMgmtInfo;
#ifdef STA_INFO_DB
    UINT8    Sq2;              /* Signal Quality 2 */
    UINT8    Sq1;              /* Signal Quality 1 */
    UINT8    Rate;             /* rate at which frame was received */
    UINT8    RSSI;             /* RF Signal Strength Indicator */
#endif
}
extStaDb_StaInfo_t;
/* */
/* The information recorded for an external station: */
/* 1) Its MAC address */
/* 2) Whether or not it is an AP */
/* 3) The state with respect to the station containing this database */
/* 4) The power mode of the external station */
/* */
#define AGING_TIMER_VALUE_IN_SECONDS   10 

/*============================================================================= */
/*                    PUBLIC PROCEDURES (ANSI Prototypes) */
/*============================================================================= */

/******************************************************************************
 *
 * Name: extStaDb_Init
 *
 * Description:
 *    Routine to initial the structures used in the external stations table.
 *
 * Conditions For Use:
 *    None.
 *
 * Arguments:
 *    None.
 *
 * Return Value:
 *    Status indicating success or failure.
 *
 * Notes:
 *    None.
 *
 *****************************************************************************/
extern WL_STATUS extStaDb_Init( UINT16 MaxStns );

/******************************************************************************
 *
 * Name: extStaDb_AddSta
 *
 * Description:
 *    This routine adds a station to the external station table.
 *
 * Conditions For Use:
 *    External station table has been initialized.
 *
 * Arguments:
 *    Arg1 (i  ): StaInfo - Pointer to a structure containing information
 *                          about the station being added
 *
 * Return Value:
 *    Status indicating the results of the operation.
 *
 * Notes:
 *    None.
 *
 *****************************************************************************/
extern extStaDb_Status_e extStaDb_AddSta ( extStaDb_StaInfo_t *StaInfo_p);

/******************************************************************************
 *
 * Name: extStaDb_DelSta
 *
 * Description:
 *    This routine deletes a station from the external station table.
 *
 * Conditions For Use:
 *    External station table has been initialized.
 *
 * Arguments:
 *    Arg1 (i  ): Addr_p  - Pointer to the MAC address of the station to be
 *                          deleted
 *
 * Return Value:
 *    Status indicating the results of the operation.
 *
 * Notes:
 *    None.
 *
 *****************************************************************************/
extern extStaDb_Status_e extStaDb_DelSta ( IEEEtypes_MacAddr_t *Addr_p, int option);

/******************************************************************************
 *
 * Name: extStaDb_GetStaInfo
 *
 * Description:
 *    This routine attempts to retrieve the state for the given MAC address.
 *
 * Conditions For Use:
 *    External station table has been initialized.
 *
 * Arguments:
 *    Arg1 (i  ): Addr_p  - Pointer to the MAC address of the station for
 *                          which the state is to be retrieved
 *    Arg2 (  o): StaInfo_p - Pointer to the variable that will contain the
 *                          requested station information
 *
 * Return Value:
 *    Status indicating the results of the operation.
 *
 * Notes:
 *    None.
 *
 *****************************************************************************/
extern extStaDb_StaInfo_t  *extStaDb_GetStaInfo( IEEEtypes_MacAddr_t *Addr_p,
            int option);

inline UINT32 Wang32BitMix( UINT32 Key ) SECTION_ITCM;

#define STADB_DONT_UPDATE_AGINGTIME 0
#define STADB_UPDATE_AGINGTIME      1
#define STADB_NO_BLOCK              3

#endif /* _EXT_STA_DB_H */
